##########################################################
#		R SCRIPT PHENOTYPIC PLASTICITY
#		  PROBABILITY OF PERSISTENCE
#
##########################################################

# to avoid conflict with decimal values separated by points
# read as factors, use dec = "." inside read.csv function
# or convert to numeric 
#using myData$fitness <- as.numeric(levels(myData$fitness))[myData$fitness]
# another alternative is to read csv as follows:
myData <- read.csv("data_previous_results.csv", stringsAsFactors = FALSE, header = T)

##########################################################
#	CHANGE NAME OF FACTORS
##########################################################
#from the web:
# Rename by name: change "beta" to "two"
#levels(x)[levels(x)=="beta"] <- "two"

#rename problematic factors

# how.plasticity.

myData$how.plasticity. <- as.factor(myData$how.plasticity.)

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == "\"random-noise\"" ] <- "random-noise"

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == "\"standard-model\""] <- "standard-model"

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == 
"\"adaptive-sinusoidal\""] <- "adaptive-sinusoidal"

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == "\"adaptive-logistic\""] <- "adaptive-logistic"

levels(myData$how.plasticity.)[levels
(myData$how.plasticity.) == "\"linear-RN\""] <- "linear-RN"


##########################################################
#	PROBABILITY OF PERSISTENCE
##########################################################

# check length of the array. It should match the number of replicates
length(myData$N[myData$density.dependence.effect == 2.5 & 
myData$level.autocorr == 0 & 
myData$rate.change.of.optimum == 0.02 &
myData$mut.rate.per.locus == 0.001 &
myData$how.plasticity. == "standard-model"])

# count number of replicates that ended in extinction
# according to specific condition 

################ NOISE COLOR FULL RANGE ####################

# The output is stored output into a matrix 
# of rows r and columns c

rate <- c(0, 0, 0, 
	    0.01, 0.02, 0.02,
	    0.02, 0.025, 0.025)
c = length(rate)
r = length(levels(as.factor(myData$level.autocorr)))

plasticity.scenarios <- c("standard-model", "random-noise",
				  "adaptive-sinusoidal", "adaptive-logistic",
				  "linear-RN")

# density effect

density <- c(0.5, 1.8, 2.5,
		 0.5, 1.8, 2.5,
		 0.5, 1.8, 2.5)

# Mutation rate

mRate <- 1e-03

# for the error bars:
# n of observations (replicates)
obs <- 100

for(k in plasticity.scenarios) 
{
	if (k == "linear-RN") { slope = 0.5 }
				else{ slope = 1   }
	
	# x stores probabiltiy of persistence
	x = matrix(0L, nrow = r, ncol = c)
	
	# y stores error
	y = matrix(0L, nrow = r, ncol = c)
	m = 1 # rows
	n = 1 # columns

	for(i in 1:length(rate))
	{
		for(j in as.numeric(levels(as.factor(myData$level.autocorr))))
		{ 
		dummy = (myData$N[myData$density.dependence.effect == density[i] & 
		   	   myData$level.autocorr == j & 
		   	   myData$rate.change.of.optimum == rate[i] &
			   myData$slope == slope &
			   myData$mut.rate.per.locus == mRate &
		   	   myData$how.plasticity. == k])

			p = length(dummy[dummy > 0]) / length(dummy)

			# error bars according to binomial distribution
			# proportion of success p
			# instead of p = 1, we assume 0.995 of success
			if(p == 1) { p = 0.995 }

			x[m,n] = p
			# obs observations (see above)
			y[m,n] = sqrt(p * (1 - p) / obs)


			m = m + 1
		}
		n = n + 1
		m = 1
	}
	# store data in vector (noP, rnd, sin, log, line)
	
	# remove columns containing only nas
	x <- x[, colSums(!is.na(x)) > 0]
	
	if( k == "standard-model") 
	{ 
		noP <- x
		noP_bars <- y
	}
	if( k == "random-noise") 
	{ 
		rnd <- x 
		rnd_bars <- y
	}
	if( k == "adaptive-sinusoidal") 
	{ 
		sin <- x 
		sin_bars <- y
	}
	if( k == "adaptive-logistic") 
	{ 
		log <- x 
		log_bars <- y
	}
	if( k == "linear-RN" ) 
	{ 
		line <- x
		line_bars <- y 
	}
	
}
##########################################################
#	ERROR BARS
# custom error bars from
# https://www.easycalculation.com/statistics/
# standard-error-sample-proportion.php
##########################################################


#################################################
#	plot 
#################################################

s = 1.4
#rate <- c(0.04, 0.03, 0.04, 0.03)
sx_axis = 1.2

for (j in 1:length(rate))#1:4)
{

	if(j == 1) {
	par(mfrow = c(3,3)) 
	}

	if(j <= 3) 
	{
		dummy <- bquote(eta == .(rate[1]) ~ " (only stochastic change)") 
	} else {
		dummy <- dummy <- bquote(eta == .(rate[j]))	
		 }


# index in array: columns specify the rate of change
i = j

# axis label

	if( j == 1 | j == 4 | j == 7) { yname = "probability of persistence" } 
	else { yname = "" }

	if ( j >= 7 ) { xname = "level of autocorrelation (noise color)"  }
	else { xname = "" }

plot(noP[,i], ylim = c(0, 1), type = "b", pch = 21, cex = s, bg = "black",
main = dummy, 
ylab = yname, 
las = 1, xaxt = "n", 
xlab = xname,
cex.lab = 1.6, cex.axis = sx_axis, cex.main = 1.6)

# add error bars noP
x = seq(from = 1, to = 9, by = 1)
arrows(x0 = x, y0 = noP[,i] - noP_bars[,i], 
	 x1 = x, y1 = noP[,i] + noP_bars[,i],
	 code = 3, angle = 90, length = 0.05) 

# error bars rnd
lines(rnd[,i], type = "b", pch = 21, cex = s, bg = "grey")
arrows(x0 = x, y0 = rnd[,i] - rnd_bars[,i], 
	 x1 = x, y1 = rnd[,i] + rnd_bars[,i],
	 code = 3, angle = 90, length = 0.05) 

# error bars sin
lines(sin[,i], type = "b", pch = 2, cex = s)#, bg = "red")
arrows(x0 = x, y0 = sin[,i] - sin_bars[,i], 
	 x1 = x, y1 = sin[,i] + sin_bars[,i],
	 code = 3, angle = 90, length = 0.05) 

# error bars log
lines(log[,i], type = "b", pch = 24, cex = s, bg = "grey")
arrows(x0 = x, y0 = log[,i] - log_bars[,i], 
	 x1 = x, y1 = log[,i] + log_bars[,i],
	 code = 3, angle = 90, length = 0.05) 

# error bars line
lines(line[,i], type = "b", pch = 8, cex = s)#, bg = "black")
arrows(x0 = x, y0 = line[,i] - line_bars[,i], 
	 x1 = x, y1 = line[,i] + line_bars[,i],
	 code = 3, angle = 90, length = 0.05) 


axis(1, at = c(1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0), 
labels = c(-0.8, -0.6, -0.4, -0.2, 0, 0.2, 0.4, 0.6, 0.8),
cex.axis = sx_axis)

	# Legend:
	if (j == 1)
	{
	legend("bottomright",#7, 0.3, 
	legend = c("genetic determinism", "random", "sinusoidal", 
	"saturating", "linear (slope = 0.5)"), col = "black",
	pch = c(21, 21, 2, 24, 8), pt.bg = c("black", "grey", "white", "grey", 
	"black"), cex = 1.4, box.lty = 0)
	}
} # end of for loop




